---
search:
  exclude: true
---
# リリースプロセス/変更履歴

本プロジェクトは、`0.Y.Z` という形式の、やや変更したセマンティック バージョニングに従います。先頭の `0` は、この SDK が依然として急速に進化していることを示します。各コンポーネントの増分は次のとおりです。

## マイナー（`Y`）バージョン

ベータではない公開インターフェースに対する **breaking changes** がある場合、マイナー バージョン `Y` を上げます。たとえば、`0.0.x` から `0.1.x` への移行には breaking changes が含まれる可能性があります。

breaking changes を避けたい場合は、プロジェクトで `0.0.x` に固定することをおすすめします。

## パッチ（`Z`）バージョン

後方互換のある変更については `Z` を増やします。

- バグ修正
- 新機能
- 非公開インターフェースの変更
- ベータ機能の更新

## 互換性を壊す変更の変更履歴

### 0.2.0

このバージョンでは、以前は引数として `Agent` を受け取っていたいくつかの箇所が、代わりに `AgentBase` を引数として受け取るようになりました。たとえば、MCP サーバーでの `list_tools()` 呼び出しです。これは純粋に型に関する変更であり、引き続き `Agent` オブジェクトを受け取ります。更新するには、`Agent` を `AgentBase` に置き換えて型エラーを解消してください。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に新しいパラメーター `run_context` と `agent` が追加されました。`MCPServer` を継承するクラスには、これらのパラメーターを追加する必要があります。